Attribute VB_Name = "modCD_Store"
Option Explicit

' Define public constants
Public Const c_iEnableAll = 0
Public Const c_iDisableAll = 1
Public Const c_iDefault = 2
Public Const c_iDirtyData = 3
Public Const c_iRecordAdd = 4
Public Const c_iRecordDelete = 5
Public Const c_iMakerAdd = 6
Public Const c_iMakerDelete = 7
Public Const c_iLocationAdd = 8
Public Const c_iLocationDelete = 9

Public Const c_bEnabled = True
Public Const c_bDisabled = False

' Define public variables
Public g_sDataPath As String
Public g_iAction As Integer
Public g_lOldRecord As Long
Public g_bDirtyData As Boolean
Public g_bLoading As Boolean

' Define public references
Public g_CD_Form As frmCD_Store
Public g_Workspace As Workspace
Public g_Database As Database
Public g_CD_Data As Recordset
Public g_CD_Makers As Recordset
Public g_CD_Location As Recordset

'==============================================================================

Public Sub Main()
  Dim l_iIndex As Integer
  Dim l_sSQL As String
  Dim l_vSettings As Variant
  
  ' Read the entries in the registry...
  Do
    l_vSettings = GetAllSettings("CD_Store", "StartUp")
    
    ' check to see if something was read from the registry. If any errors
    ' occurred during the read then VarType() will be 0...
    If VarType(l_vSettings) = 0 Then
    
      ' there's no entry in the registry...
      l_vSettings = WriteRegistryEntries()
    Else
    
      ' fill the appropriate variables with the registry data...
      For l_iIndex = LBound(l_vSettings, 1) To UBound(l_vSettings, 1)
        Select Case l_vSettings(l_iIndex, 0)
          Case "DataPath"
            g_sDataPath = l_vSettings(l_iIndex, 1)
        End Select
      Next
      
      ' and exit the loop...
      Exit Do
    End If
    
    ' loop back and start again.
  Loop
  
  ' Load the form...
  Set g_CD_Form = frmCD_Store
  Load g_CD_Form
  
  ' load the database...
  Set g_Workspace = Workspaces(0)
  Set g_Database = g_Workspace.OpenDatabase(g_sDataPath & "cd_store.mdb")
  Set g_CD_Data = g_Database.OpenRecordset("CD_Data", dbOpenDynaset)
  g_CD_Data.MoveLast
  Set g_CD_Makers = g_Database.OpenRecordset("Makers", dbOpenDynaset)
  Set g_CD_Location = g_Database.OpenRecordset("Location", dbOpenDynaset)
        
  ' fill the combo boxes...
  Call LoadMakers
  Call LoadLocations
  
  ' and populate the form.
  g_CD_Data.MoveFirst
  Call PopulateForm
  g_iAction = c_iDefault
  g_CD_Form.Show vbModal
End Sub

'==============================================================================

Public Function WriteRegistryEntries() As Variant
  Dim l_sReturn As String
  Dim l_iCheck As Integer
  
  ' Get the neccessary data from the user and write it to the
  ' appropriate registry entry...
  Do
    l_sReturn = InputBox("Enter the full path to the database 'CD_Store.mdb'", _
                          "CD Store", CStr(CurDir))
    If l_sReturn = "" Then
    
      ' the Input Box cancel button has been pressed so, as the program can't
      ' continue without this data, exit the program.
      Call QuitRoutine(False)
    End If
    
    ' check that the input path actually points to the database...
    If Right(l_sReturn, 1) <> "\" Then
      l_sReturn = l_sReturn & "\"
    End If
    If Dir(l_sReturn & "cd_store.mdb") <> "" Then
    
      'it does, so write the registry entry and exit the loop.
      Call SaveSetting("CD_Store", "StartUp", "DataPath", l_sReturn)
      Exit Do
    End If
    
    ' it doesn't so inform the user and loop back.
    l_iCheck = UserMessage(1, l_sReturn)
  Loop
End Function

'==============================================================================

Public Sub QuitRoutine(ByVal p_bShowMessage As Boolean)
  If p_bShowMessage Then
    If UserMessage(0, "") = vbNo Then
      Exit Sub
    End If
  End If
  End
End Sub

'==============================================================================

Public Sub CentreForm(ByVal p_Form As Form)
  
  ' Centre the form on-screen and pop it to the top of the window stack
  p_Form.Left = (Screen.Width - p_Form.Width) \ 2
  p_Form.Top = (Screen.Height - p_Form.Height) \ 2
  p_Form.ZOrder
End Sub

'==============================================================================

Public Function UserMessage(ByVal p_iIndex As Integer, _
                            ByVal p_sExtraText As String) As Integer
  Dim l_sTitle As String, l_sMessage As String
  Dim l_iBoxType As Integer
  
  ' A universal message box call. Select the message to send, the type of
  ' icon and the buttons to show...
  l_sTitle = "CD Store"
  Select Case p_iIndex
    Case 0
      l_sMessage = "Do you really want to quit?"
      l_iBoxType = vbQuestion + vbYesNo
    Case 1
      l_sMessage = "The path " & p_sExtraText & " is incorrect"
      l_iBoxType = vbExclamation + vbOKOnly
    Case 2
      l_sMessage = "The current record has been modified" & Chr(13) & _
                   "Continue and lose the changes?"
      l_iBoxType = vbQuestion + vbYesNo + vbDefaultButton2
    Case 3
      l_sMessage = "The database " & p_sExtraText & " failed"
      l_iBoxType = vbExclamation + vbOKOnly
    Case 4
      l_sMessage = "Delete the current " & p_sExtraText & "?"
      l_iBoxType = vbQuestion + vbYesNo + vbDefaultButton2
    Case 5
      l_sMessage = "The manufacturer " & p_sExtraText & " failed"
      l_iBoxType = vbExclamation + vbOKOnly
    Case 6
      l_sMessage = "The location " & p_sExtraText & " failed"
      l_iBoxType = vbExclamation + vbOKOnly
    Case 7
      l_sMessage = "You must select a " & p_sExtraText & " to delete"
      l_iBoxType = vbExclamation + vbOKOnly
    Case 8
      l_sMessage = "Are you sure you want to delete '" & p_sExtraText & "'?"
      l_iBoxType = vbQuestion + vbYesNo + vbDefaultButton2
    Case 9
      l_sMessage = "The item '" & p_sExtraText & "' selected for deletion "
      l_sMessage = l_sMessage & "could not be found"
      l_iBoxType = vbExclamation + vbOKOnly
  End Select
  
  ' then show it and return the user's response.
  Beep
  UserMessage = MsgBox(l_sMessage, l_iBoxType, l_sTitle)
End Function

'==============================================================================

Public Sub PopulateForm()
  Dim l_sSQL As String
  Dim l_iIndex As Integer
  
  ' Populate the form with data from the current database record.
  g_bLoading = True
  With g_CD_Form
    
    ' Add the title...
    If Not IsNull(g_CD_Data!Title) Then
      .txtTitle = g_CD_Data!Title
    Else
      .txtTitle = ""
    End If
    
    ' the manufacturer...
    If Not IsNull(g_CD_Data!Maker) Then
      l_sSQL = "ID = " & CStr(g_CD_Data!Maker)
      g_CD_Makers.FindFirst l_sSQL
      If Not g_CD_Makers.NoMatch Then
        If Not IsNull(g_CD_Makers!Name) Then
          .cboMaker = g_CD_Makers!Name
        Else
          .cboMaker = ""
        End If
      End If
    Else
      .cboMaker = ""
    End If
    
    ' the key code...
    If Not IsNull(g_CD_Data!Code) Then
      .txtCode = g_CD_Data!Code
    Else
      .txtCode = ""
    End If
    
    ' the contents...
    If Not IsNull(g_CD_Data!Contents) Then
      .txtContents = g_CD_Data!Contents
    Else
      .txtContents = ""
    End If
    
    ' the caddy number...
    If Not IsNull(g_CD_Data!Caddy) Then
      .txtCaddy = g_CD_Data!Caddy
    Else
      .txtCaddy = ""
    End If
    
    ' the slot number...
    If Not IsNull(g_CD_Data!Slot) Then
      .txtSlot = g_CD_Data!Slot
    Else
      .txtSlot = ""
    End If
    
    ' and the location.
    If Not IsNull(g_CD_Data!Location) Then
      l_sSQL = "ID = " & CStr(g_CD_Data!Location)
      g_CD_Location.FindFirst l_sSQL
      If Not g_CD_Location.NoMatch Then
        If Not IsNull(g_CD_Location!Location) Then
          .cboLocation = g_CD_Location!Location
        Else
          .cboLocation = ""
        End If
      End If
    Else
      .cboLocation = ""
    End If
  
    ' En/disable the speed buttons and menu items.
    Call SetButtonsAndMenus(c_iDefault)
  End With
  g_bDirtyData = False
  g_bLoading = False
End Sub

'==============================================================================

Public Sub MoveFirst()
  g_CD_Data.MoveFirst
  PopulateForm
End Sub

'==============================================================================

Public Sub MovePrevious()
  g_CD_Data.MovePrevious
  If g_CD_Data.BOF Then
    Beep
    g_CD_Data.MoveFirst
  End If
  PopulateForm
End Sub

'==============================================================================

Public Sub MoveNext()
  g_CD_Data.MoveNext
  If g_CD_Data.EOF Then
    Beep
    g_CD_Data.MoveLast
  End If
  PopulateForm
End Sub

'==============================================================================

Public Sub MoveLast()
  g_CD_Data.MoveLast
  PopulateForm
End Sub

'==============================================================================

Public Function DatabaseWrite() As Boolean
  Dim l_iCheck As Integer
  On Error GoTo CheckError
  
  DatabaseWrite = True
  Select Case g_iAction
    Case c_iRecordAdd
      
      ' Add a record...
      g_CD_Data.AddNew
    Case c_iMakerAdd
    
      ' Add a manufacturer...
      l_iCheck = GetMakersID(g_CD_Form.cboMaker)
      If l_iCheck < g_CD_Makers.RecordCount Then
        l_iCheck = UserMessage(5, "add")
        Exit Function
      End If
    
      ' and rewrite the combo box
      g_CD_Form.cboMaker.Clear
      g_CD_Makers.MoveFirst
      While Not g_CD_Makers.EOF
        g_CD_Form.cboMaker.AddItem g_CD_Makers!Name
        g_CD_Makers.MoveNext
      Wend
      Call SetFormItems(c_bEnabled)
      Call PopulateForm
      g_iAction = c_iDefault
      Exit Function
    Case c_iLocationAdd
    
      ' Add a location...
      l_iCheck = GetLocationID(g_CD_Form.cboLocation)
      If l_iCheck < g_CD_Location.RecordCount Then
        l_iCheck = UserMessage(6, "add")
        Exit Function
      End If
      
      ' and rewrite the combo box
      g_CD_Form.cboLocation.Clear
      g_CD_Location.MoveFirst
      While Not g_CD_Location.EOF
        g_CD_Form.cboLocation.AddItem g_CD_Location!Location
        g_CD_Location.MoveNext
      Wend
      Call SetFormItems(c_bEnabled)
      Call PopulateForm
      g_iAction = c_iDefault
      Exit Function
    Case Else
      
      ' Edit a record...
      g_CD_Data.Edit
  End Select
  
  ' Write the data on the form to the database.
  With g_CD_Form
    g_CD_Data!Title = .txtTitle
    g_CD_Data!Contents = .txtContents
    g_CD_Data!Code = .txtCode
    If .txtCaddy = "" Then
      g_CD_Data!Caddy = 0
    Else
      g_CD_Data!Caddy = CInt(.txtCaddy)
    End If
    If .txtSlot = "" Then
      g_CD_Data!Slot = 0
    Else
      g_CD_Data!Slot = .txtSlot
    End If
    
    ' Get the ID of the maker's name from the Makers table and the ID of the
    ' location from the Location table...
    If .cboMaker <> "" Then
      l_iCheck = GetMakersID(.cboMaker)
      If l_iCheck > -1 Then
        g_CD_Data!Maker = l_iCheck
      Else
        Err.Raise vbObjectError + 1
      End If
    End If
    If .cboLocation <> "" Then
      l_iCheck = GetLocationID(.cboLocation)
      If l_iCheck > -1 Then
        g_CD_Data!Location = l_iCheck
      Else
        Err.Raise vbObjectError + 1
      End If
    End If
  End With
  g_CD_Data.Update
  g_CD_Data.Requery
  Call PopulateForm
  Call SetButtonsAndMenus(c_iDefault)
  g_iAction = c_iDefault
  g_bDirtyData = False
Exit Function

CheckError:

  ' Set the return to the fault value
  DatabaseWrite = False
End Function

'==============================================================================

Public Function GetMakersID(ByVal p_sName As String) As Integer
  On Error GoTo CheckError
  
  g_CD_Makers.MoveFirst
  While Not g_CD_Makers.EOF
    If LCase(g_CD_Makers!Name) = LCase(p_sName) Then
    
      ' The passed name is already in the table so return the ID...
      GetMakersID = g_CD_Makers!ID
      Exit Function
    End If
    g_CD_Makers.MoveNext
  Wend
  
  ' and if the passed name hasn't been found then add it and return the ID.
  g_CD_Makers.AddNew
  g_CD_Makers!Name = p_sName
  GetMakersID = g_CD_Makers!ID
  g_CD_Makers.Update
  Call LoadMakers
Exit Function

CheckError:

  ' Set the return to the fault value
  GetMakersID = -1
End Function

'==============================================================================

Public Function GetLocationID(ByVal p_sLocation As String) As Integer
  On Error GoTo CheckError
  
  While Not g_CD_Location.EOF
    If LCase(g_CD_Location!Location) = LCase(p_sLocation) Then
    
      ' The passed location is already in the table so return the ID...
      GetLocationID = g_CD_Location!ID
      Exit Function
    End If
    g_CD_Location.MoveNext
  Wend
  
  ' and if the passed name hasn't been found then add it and return the ID.
  g_CD_Location.AddNew
  g_CD_Location!Location = p_sLocation
  GetLocationID = g_CD_Location!ID
  g_CD_Location.Update
  Call LoadLocations
Exit Function

CheckError:

  ' Set the return to the fault value
  GetLocationID = -1
End Function

'==============================================================================

Public Function DatabaseAdd() As Boolean
  Dim l_iIndex As Integer
  On Error GoTo CheckError
  
  DatabaseAdd = True
  
  ' Set up the form ready to accept a new record.
  g_lOldRecord = g_CD_Data!ID
  g_bLoading = True
  With g_CD_Form
    .txtTitle = ""
    .cboMaker = ""
    .txtCode = ""
    .txtContents = ""
    .txtCaddy = ""
    .txtSlot = ""
    .cboLocation = ""
    .txtTitle.SetFocus
    Call SetButtonsAndMenus(c_iRecordAdd)
  End With
  g_bLoading = False
Exit Function

CheckError:

  ' Set the return to the fault value
  DatabaseAdd = False
End Function

'==============================================================================

Public Function DatabaseDelete() As Boolean
  Dim l_sTemp As String
  Dim l_bFound As Boolean
  Dim l_iCheck As Integer
  Dim l_lCount As Long, l_lCurrentRecord As Long
  On Error GoTo CheckError
  
  DatabaseDelete = True
  Select Case g_iAction
    Case c_iRecordDelete
      If UserMessage(4, "record") = vbYes Then
        l_lCount = g_CD_Data.AbsolutePosition
        g_CD_Data.Delete
        g_CD_Data.Close
        Set g_CD_Data = g_Database.OpenRecordset("CD_Data", dbOpenDynaset)
        If g_CD_Data.RecordCount < l_lCount Then
          l_lCount = l_lCount - 1
        End If
        g_CD_Data.Move l_lCount
      End If
      Call PopulateForm
    Case c_iMakerDelete
    
      ' Delete a manufacturer...
      If g_CD_Form.cboMaker = "" Then
        l_iCheck = UserMessage(7, "manufacturer")
        Exit Function
      Else
  
        ' Find the maker-to-delete's record...
        l_sTemp = g_CD_Form.cboMaker
        l_iCheck = GetMakersID(l_sTemp)
        If l_iCheck = -1 Then
        
          ' the maker isn't in the database...
          l_iCheck = UserMessage(9, l_sTemp)
          Err.Raise vbObjectError + 1
        Else
        
          ' check that the maker isn't being called by any records in the main
          ' database...
          With g_CD_Data
            l_lCurrentRecord = !ID
            .FindFirst "Maker = " & CStr(l_iCheck)
            If Not .NoMatch Then
            
              ' it is, so make sure it should be deleted...
              l_sTemp = l_sTemp & ", which is still in use"
            End If
          End With
          If UserMessage(8, l_sTemp) = vbYes Then
            g_CD_Makers.Delete
            g_CD_Data.FindFirst "ID = " & CStr(l_lCurrentRecord)
            Call LoadMakers
            Call PopulateForm
            Call SetFormItems(c_bEnabled)
          End If
        End If
      End If
    Case c_iLocationDelete
    
      ' Delete a location...
      If g_CD_Form.cboLocation = "" Then
        l_iCheck = UserMessage(7, "location")
        Exit Function
      Else
  
        ' Find the location-to-delete's record...
        l_sTemp = g_CD_Form.cboLocation
        l_iCheck = GetLocationID(l_sTemp)
        If l_iCheck = -1 Then
        
          ' the maker isn't in the database...
          l_iCheck = UserMessage(9, l_sTemp)
          Err.Raise vbObjectError + 1
        Else
        
          ' check that the location isn't being called by any records in the
          ' main database...
          With g_CD_Data
            l_lCurrentRecord = !ID
            .FindFirst "Location = " & CStr(l_iCheck)
            If Not .NoMatch Then
            
              ' it is, so make sure it should be deleted...
              l_sTemp = l_sTemp & ", which is still in use"
            End If
          End With
          If UserMessage(8, l_sTemp) = vbYes Then
            g_CD_Location.Delete
            g_CD_Data.FindFirst "ID = " & CStr(l_lCurrentRecord)
            Call LoadLocations
            Call PopulateForm
            Call SetFormItems(c_bEnabled)
          End If
        End If
      End If
  End Select
  Call SetButtonsAndMenus(c_iDefault)
  g_iAction = c_iDefault
Exit Function

CheckError:

  ' Set the return to the fault value
  DatabaseDelete = False
End Function

'==============================================================================

Public Function DatabaseCancel()
  Dim l_sSQL As String
  On Error GoTo CheckError
  
  DatabaseCancel = True
  l_sSQL = "ID = " & CStr(g_lOldRecord)
  g_CD_Data.FindFirst l_sSQL
  g_bDirtyData = False
  Call SetButtonsAndMenus(c_iDefault)
  Call PopulateForm
Exit Function

CheckError:

  ' Set the return to the fault value
  DatabaseCancel = False
End Function

'==============================================================================

Public Sub SetButtonsAndMenus(ByVal p_iAction As Integer)
  Dim l_iIndex As Integer
  
  Select Case p_iAction
    Case c_iEnableAll
    
      ' Enable all the buttons and menu items...
      Call SetSpeedButtons(c_bEnabled)
      Call SetNavigateButtons(c_bEnabled)
      Call SetDatbaseMenu(c_bEnabled)
      Call SetNavigateMenu(c_bEnabled)
    Case c_iDisableAll
    
      ' Disable all the buttons and menu items...
      Call SetSpeedButtons(c_bDisabled)
      Call SetNavigateButtons(c_bDisabled)
      Call SetDatbaseMenu(c_bDisabled)
      Call SetNavigateMenu(c_bDisabled)
    Case c_iDefault
    
      ' En/disable all buttons and menu items to normal...
      Call SetSpeedButtons(c_bEnabled)
      Call SetDatbaseMenu(c_bEnabled)
      With g_CD_Form
        .cmdSpeedButton(2).Enabled = c_bDisabled
        .cmdSpeedButton(3).Enabled = c_bDisabled
        .mnuDatabase(2).Enabled = c_bDisabled
        .mnuDatabase(4).Enabled = c_bDisabled
        If g_CD_Data.RecordCount = -1 Then
          .cmdSpeedButton(1).Enabled = c_bDisabled
          .mnuDatabase(1).Enabled = c_bDisabled
        End If
      End With
      Call SetNavigateButtons(c_bEnabled)
      Call SetNavigateMenu(c_bEnabled)
    Case c_iRecordAdd, c_iRecordDelete, c_iMakerAdd, c_iMakerDelete, _
         c_iLocationAdd, c_iLocationDelete
    
      ' En/disable the active buttons when the user is adding a record...
      With g_CD_Form
        For l_iIndex = 0 To 1
          .cmdSpeedButton(l_iIndex).Enabled = c_bDisabled
          .mnuDatabase(l_iIndex).Enabled = c_bDisabled
        Next
        .cmdSpeedButton(2).Enabled = c_bEnabled
        .cmdSpeedButton(3).Enabled = c_bEnabled
        .mnuDatabase(2).Enabled = c_bEnabled
        .mnuDatabase(4).Enabled = c_bEnabled
      End With
      Call SetNavigateButtons(c_bDisabled)
      Call SetNavigateMenu(c_bDisabled)
    Case c_iDirtyData
    
      ' Enable the Accept button if the form is modified...
      If Not g_bLoading Then
        g_bDirtyData = True
        g_CD_Form.cmdSpeedButton(2).Enabled = c_bEnabled
        g_CD_Form.cmdSpeedButton(3).Enabled = c_bEnabled
      End If
  End Select
End Sub

'==============================================================================

Public Sub SetSpeedButtons(ByVal p_bEnabled As Integer)
  Dim l_iIndex As Integer
    
  ' Set all the speed buttons
  For l_iIndex = 0 To 4
    g_CD_Form.cmdSpeedButton(l_iIndex).Enabled = p_bEnabled
  Next
End Sub

'==============================================================================

Public Sub SetDatbaseMenu(ByVal p_bEnabled As Integer)
  Dim l_iIndex As Integer
    
  ' Set all the database menu items
  For l_iIndex = 0 To 2
    g_CD_Form.mnuDatabase(l_iIndex).Enabled = p_bEnabled
  Next
  g_CD_Form.mnuDatabase(4).Enabled = p_bEnabled
End Sub

'==============================================================================

Public Sub SetNavigateButtons(ByVal p_bEnabled As Integer)
  Dim l_iIndex As Integer
    
  ' Set all the navigation buttons
  For l_iIndex = 0 To 3
    g_CD_Form.cmdNavigate(l_iIndex).Enabled = p_bEnabled
  Next
End Sub

'==============================================================================

Public Sub SetNavigateMenu(ByVal p_bEnabled As Integer)
  Dim l_iIndex As Integer
    
  ' Set all the navigation buttons
  For l_iIndex = 0 To 3
    g_CD_Form.mnuNavigate(l_iIndex).Enabled = p_bEnabled
  Next
End Sub

'==============================================================================

Public Function MakerAdd() As Boolean
  On Error GoTo CheckError
  
  MakerAdd = True
  
  ' Disable the navigation buttons, the unused speed buttons and menu items...
  Call SetButtonsAndMenus(c_iMakerAdd)
  
  ' Disable everything on the form except the Manufacturer drop-down
  ' combo box...
  Call SetFormItems(c_bDisabled)
  g_CD_Form.cboMaker.Enabled = c_bEnabled

  ' then clear the text entry area...
  g_CD_Form.cboMaker = ""
  g_iAction = c_iMakerAdd
  g_CD_Form.cboMaker.SetFocus
Exit Function

CheckError:

  ' Set the return to the fault value
  MakerAdd = False
End Function

'==============================================================================

Public Function LocationAdd() As Boolean
  On Error GoTo CheckError
  
  LocationAdd = True
  
  ' Disable everything on the form except the Location drop-down combo
  ' box...
  Call SetFormItems(c_bDisabled)
  Call SetButtonsAndMenus(c_iLocationAdd)
  g_CD_Form.cboLocation.Enabled = c_bEnabled

  ' then clear the text entry area...
  g_CD_Form.cboLocation = ""
  g_iAction = c_iLocationAdd
  g_CD_Form.cboLocation.SetFocus
Exit Function

CheckError:

  ' Set the return to the fault value
  LocationAdd = False
End Function

'==============================================================================

Public Function LocationDelete()
  Dim l_iCheck As Integer
  On Error GoTo CheckError
  
  LocationDelete = True
  g_iAction = c_iLocationDelete

  ' Disable everything on the form except the Manufacturer drop-down
  ' combo box...
  Call SetFormItems(c_bDisabled)
  g_CD_Form.cboLocation.Enabled = c_bEnabled
  Call SetButtonsAndMenus(c_iLocationDelete)
  g_CD_Form.cboLocation.SetFocus
Exit Function

CheckError:

  ' Set the return to the fault value
  LocationDelete = False
End Function

'==============================================================================

Public Sub SetFormItems(ByVal p_bAction As Boolean)

  ' En/disable everything on the form...
  With g_CD_Form
    .txtTitle.Enabled = p_bAction
    .cboMaker.Enabled = p_bAction
    .txtCode.Enabled = p_bAction
    .txtContents.Enabled = p_bAction
    .txtCaddy.Enabled = p_bAction
    .txtSlot.Enabled = p_bAction
    .cboLocation.Enabled = p_bAction
  End With
End Sub

'==============================================================================

Public Function MakerDelete()
  Dim l_iCheck As Integer
  On Error GoTo CheckError
  
  MakerDelete = True
  g_iAction = c_iMakerDelete

  ' Disable everything on the form except the Manufacturer drop-down
  ' combo box...
  Call SetFormItems(c_bDisabled)
  g_CD_Form.cboMaker.Enabled = c_bEnabled
  Call SetButtonsAndMenus(c_iMakerDelete)
  g_CD_Form.cboMaker.SetFocus
Exit Function

CheckError:

  ' Set the return to the fault value
  MakerDelete = False
End Function

'==============================================================================

Public Sub LoadMakers()

  ' Load all manufacturers to the manufacturers drop down combo box...
  g_CD_Form.cboMaker.Clear
  g_CD_Makers.MoveFirst
  While Not g_CD_Makers.EOF
    g_CD_Form.cboMaker.AddItem g_CD_Makers!Name
    g_CD_Makers.MoveNext
  Wend
End Sub
'==============================================================================

Public Sub LoadLocations()

  ' Load all locations to the location drop down combo box...
  g_CD_Form.cboLocation.Clear
  g_CD_Location.MoveFirst
  While Not g_CD_Location.EOF
    g_CD_Form.cboLocation.AddItem g_CD_Location!Location
    g_CD_Location.MoveNext
  Wend
End Sub

